@@ -38,7 +38,7 @@ fn total(b: &mut Bencher) {
                 res?
             };
 
-            let s = swc_webpack_ast::webpack_ast(cm.clone(), fm.clone(), module).unwrap();
+            let s = swc_webpack_ast::webpack_ast(cm.clone(), fm.clone(), module.into()).unwrap();
             println!("{} bytes", s.len());
 
             Ok(())
